import { composableNames, unpackMeta } from '@unhead/shared';
import { toRef, isRef, ref, watchEffect, watch, getCurrentInstance, shallowRef, onServerPrefetch, useSSRContext, unref, withCtx, createVNode, createTextVNode, defineComponent, h, resolveComponent, computed } from 'vue';
import { u as useNuxtApp, i as injectHead, r as resolveUnrefHeadInput, b as asyncDataDefaults, _ as _export_sfc, c as createError, a as useRoute, d as useRouter, n as nuxtLinkDefaults, h as hashMode, e as resolveRouteObject, f as navigateTo, g as useRuntimeConfig } from './server.mjs';
import { ssrRenderAttrs, ssrRenderStyle, ssrInterpolate, ssrRenderAttr, ssrRenderComponent } from 'vue/server-renderer';
import { ElDialog } from 'element-plus';
import Cookie from 'js-cookie';
import { p as parseQuery, h as hasProtocol, j as joinURL, e as withTrailingSlash, f as withoutTrailingSlash } from '../_/nitro.mjs';

function useHead(input, options = {}) {
  const head = options.head || injectHead();
  if (head) {
    if (!head.ssr)
      return clientUseHead(head, input, options);
    return head.push(input, options);
  }
}
function clientUseHead(head, input, options = {}) {
  const deactivated = ref(false);
  const resolvedInput = ref({});
  watchEffect(() => {
    resolvedInput.value = deactivated.value ? {} : resolveUnrefHeadInput(input);
  });
  const entry = head.push(resolvedInput.value, options);
  watch(resolvedInput, (e) => {
    entry.patch(e);
  });
  getCurrentInstance();
  return entry;
}
const coreComposableNames = [
  "injectHead"
];
({
  "@unhead/vue": [...coreComposableNames, ...composableNames]
});
function useSeoMeta(input, options) {
  const { title, titleTemplate, ...meta } = input;
  return useHead({
    title,
    titleTemplate,
    // @ts-expect-error runtime type
    _flatMeta: meta
  }, {
    ...options,
    transform(t) {
      const meta2 = unpackMeta({ ...t._flatMeta });
      delete t._flatMeta;
      return {
        // @ts-expect-error runtime type
        ...t,
        meta: meta2
      };
    }
  });
}
const ACCESS_TOKEN_KEY = "adminToken";
function setToken(token) {
  Cookie.set(ACCESS_TOKEN_KEY, token, { expires: 7 });
}
function getToken() {
  return Cookie.get(ACCESS_TOKEN_KEY);
}
const ACCESS_TICKET_KEY = "ticket";
function setTicket(ticket) {
  Cookie.set(ACCESS_TICKET_KEY, ticket, { expires: 7 });
}
const useStateKeyPrefix = "$s";
function useState(...args) {
  const autoKey = typeof args[args.length - 1] === "string" ? args.pop() : undefined;
  if (typeof args[0] !== "string") {
    args.unshift(autoKey);
  }
  const [_key, init] = args;
  if (!_key || typeof _key !== "string") {
    throw new TypeError("[nuxt] [useState] key must be a string: " + _key);
  }
  if (init !== undefined && typeof init !== "function") {
    throw new Error("[nuxt] [useState] init must be a function: " + init);
  }
  const key = useStateKeyPrefix + _key;
  const nuxtApp = useNuxtApp();
  const state = toRef(nuxtApp.payload.state, key);
  if (state.value === undefined && init) {
    const initialValue = init();
    if (isRef(initialValue)) {
      nuxtApp.payload.state[key] = initialValue;
      return initialValue;
    }
    state.value = initialValue;
  }
  return state;
}
const isDefer = (dedupe) => dedupe === "defer" || dedupe === false;
function useAsyncData(...args) {
  var _a2, _b2, _c, _d, _e, _f, _g, _h;
  var _b;
  const autoKey = typeof args[args.length - 1] === "string" ? args.pop() : undefined;
  if (typeof args[0] !== "string") {
    args.unshift(autoKey);
  }
  let [key, _handler, options = {}] = args;
  if (typeof key !== "string") {
    throw new TypeError("[nuxt] [asyncData] key must be a string.");
  }
  if (typeof _handler !== "function") {
    throw new TypeError("[nuxt] [asyncData] handler must be a function.");
  }
  const nuxtApp = useNuxtApp();
  const handler = _handler ;
  const getDefault = () => asyncDataDefaults.value;
  const getDefaultCachedData = () => nuxtApp.isHydrating ? nuxtApp.payload.data[key] : nuxtApp.static.data[key];
  options.server = (_a2 = options.server) != null ? _a2 : true;
  options.default = (_b2 = options.default) != null ? _b2 : getDefault;
  options.getCachedData = (_c = options.getCachedData) != null ? _c : getDefaultCachedData;
  options.lazy = (_d = options.lazy) != null ? _d : false;
  options.immediate = (_e = options.immediate) != null ? _e : true;
  options.deep = (_f = options.deep) != null ? _f : asyncDataDefaults.deep;
  options.dedupe = (_g = options.dedupe) != null ? _g : "cancel";
  const initialCachedData = options.getCachedData(key, nuxtApp);
  const hasCachedData = initialCachedData != null;
  if (!nuxtApp._asyncData[key] || !options.immediate) {
    (_h = (_b = nuxtApp.payload._errors)[key]) != null ? _h : _b[key] = asyncDataDefaults.errorValue;
    const _ref = options.deep ? ref : shallowRef;
    nuxtApp._asyncData[key] = {
      data: _ref(hasCachedData ? initialCachedData : options.default()),
      pending: ref(!hasCachedData),
      error: toRef(nuxtApp.payload._errors, key),
      status: ref("idle"),
      _default: options.default
    };
  }
  const asyncData = { ...nuxtApp._asyncData[key] };
  delete asyncData._default;
  asyncData.refresh = asyncData.execute = (opts = {}) => {
    var _a3;
    if (nuxtApp._asyncDataPromises[key]) {
      if (isDefer((_a3 = opts.dedupe) != null ? _a3 : options.dedupe)) {
        return nuxtApp._asyncDataPromises[key];
      }
      nuxtApp._asyncDataPromises[key].cancelled = true;
    }
    if (opts._initial || nuxtApp.isHydrating && opts._initial !== false) {
      const cachedData = opts._initial ? initialCachedData : options.getCachedData(key, nuxtApp);
      if (cachedData != null) {
        return Promise.resolve(cachedData);
      }
    }
    asyncData.pending.value = true;
    asyncData.status.value = "pending";
    const promise = new Promise(
      (resolve, reject) => {
        try {
          resolve(handler(nuxtApp));
        } catch (err) {
          reject(err);
        }
      }
    ).then(async (_result) => {
      if (promise.cancelled) {
        return nuxtApp._asyncDataPromises[key];
      }
      let result = _result;
      if (options.transform) {
        result = await options.transform(_result);
      }
      if (options.pick) {
        result = pick(result, options.pick);
      }
      nuxtApp.payload.data[key] = result;
      asyncData.data.value = result;
      asyncData.error.value = asyncDataDefaults.errorValue;
      asyncData.status.value = "success";
    }).catch((error) => {
      if (promise.cancelled) {
        return nuxtApp._asyncDataPromises[key];
      }
      asyncData.error.value = createError(error);
      asyncData.data.value = unref(options.default());
      asyncData.status.value = "error";
    }).finally(() => {
      if (promise.cancelled) {
        return;
      }
      asyncData.pending.value = false;
      delete nuxtApp._asyncDataPromises[key];
    });
    nuxtApp._asyncDataPromises[key] = promise;
    return nuxtApp._asyncDataPromises[key];
  };
  asyncData.clear = () => clearNuxtDataByKey(nuxtApp, key);
  const initialFetch = () => asyncData.refresh({ _initial: true });
  const fetchOnServer = options.server !== false && nuxtApp.payload.serverRendered;
  if (fetchOnServer && options.immediate) {
    const promise = initialFetch();
    if (getCurrentInstance()) {
      onServerPrefetch(() => promise);
    } else {
      nuxtApp.hook("app:created", async () => {
        await promise;
      });
    }
  }
  const asyncDataPromise = Promise.resolve(nuxtApp._asyncDataPromises[key]).then(() => asyncData);
  Object.assign(asyncDataPromise, asyncData);
  return asyncDataPromise;
}
function clearNuxtDataByKey(nuxtApp, key) {
  if (key in nuxtApp.payload.data) {
    nuxtApp.payload.data[key] = undefined;
  }
  if (key in nuxtApp.payload._errors) {
    nuxtApp.payload._errors[key] = asyncDataDefaults.errorValue;
  }
  if (nuxtApp._asyncData[key]) {
    nuxtApp._asyncData[key].data.value = undefined;
    nuxtApp._asyncData[key].error.value = asyncDataDefaults.errorValue;
    nuxtApp._asyncData[key].pending.value = false;
    nuxtApp._asyncData[key].status.value = "idle";
  }
  if (key in nuxtApp._asyncDataPromises) {
    if (nuxtApp._asyncDataPromises[key]) {
      nuxtApp._asyncDataPromises[key].cancelled = true;
    }
    nuxtApp._asyncDataPromises[key] = undefined;
  }
}
function pick(obj, keys) {
  const newObj = {};
  for (const key of keys) {
    newObj[key] = obj[key];
  }
  return newObj;
}
function requestDataPromise(url, options = {}) {
  return new Promise(async (resolve, reject) => {
    const { $webUrl, $userUrl, $CwebUrl } = useNuxtApp();
    let fullUrl = $webUrl + url;
    let key = `${url}-${JSON.stringify(options.query)}`;
    const headers = {
      "Content-Type": "application/json",
      "Userurl": $CwebUrl,
      "token": getToken(),
      "Origin": $CwebUrl
    };
    const method = options.method || "GET";
    try {
      const { data, error } = await useAsyncData(key, () => {
        return $fetch(fullUrl, {
          method,
          headers,
          body: method === "POST" ? options.body : void 0,
          // 仅在 POST 请求时设置 body
          query: method === "GET" ? options.query : void 0
          // 仅在 GET 请求时设置 query
        });
      }, {
        lazy: false
      });
      if (error.value) {
        reject(error.value);
      } else {
        resolve(data.value);
      }
    } catch (err) {
      reject(err);
    }
  });
}
function requestHome(url, options = {}) {
  return new Promise(async (resolve, reject) => {
    const { $webUrl, $userUrl, $CwebUrl } = useNuxtApp();
    let fullUrl = $webUrl + url;
    let key = `${url}-${JSON.stringify(options.query)}`;
    const headers = {
      "Content-Type": "application/json",
      "Userurl": $CwebUrl,
      "token": getToken(),
      "Origin": $CwebUrl
    };
    const method = options.method || "GET";
    try {
      const { data, error } = await useAsyncData(key, () => {
        return $fetch(fullUrl, {
          method,
          headers,
          body: method === "POST" ? options.body : void 0,
          // 仅在 POST 请求时设置 body
          query: method === "GET" ? options.query : void 0
          // 仅在 GET 请求时设置 query
        });
      }, {
        lazy: true
        //使用缓存
      });
      if (error.value) {
        reject(error.value);
      } else {
        resolve(data.value);
      }
    } catch (err) {
      reject(err);
    }
  });
}
const _sfc_main = {
  __name: "pageHead",
  __ssrInlineRender: true,
  setup(__props) {
    useNuxtApp();
    let ticket = ref("");
    let token = ref("");
    let route = useRoute();
    ticket.value = route.query.ticket;
    token.value = route.query.admintoken;
    if (ticket.value) {
      setTicket(ticket.value);
    }
    if (token.value) {
      setToken(token.value);
    }
    useState("keyword", () => "");
    let username = useState("username", () => "\u7528\u6237\u4E2D\u5FC3");
    useState("isDel", () => 1);
    let isShow = useState("isShow", () => false);
    let token1 = useState("token1", () => "");
    let showToken = useState("showToken", () => "");
    token1.value = getToken();
    let tokenStatus = ref("");
    tokenStatus.value = getToken();
    if (tokenStatus.value == undefined) {
      console.log("SSR waring ---------- SSR waring ---------- SSR waring ---------->");
      console.log("\u9519\u8BEF\uFF1A\u672A\u83B7\u53D6\u5230\u7528\u6237token,\u5982\u679C\u5728\u672C\u5730\u6D4B\u8BD5\u8BF7\u5FFD\u7565\uFF01");
      console.log("SSR waring ---------- SSR waring ---------- SSR waring ---------->");
    } else {
      console.log(tokenStatus.value);
    }
    let dialogTableVisible = ref(false);
    watch(token1, (newval, oldval) => {
      showToken.value = newval;
    }, {
      deep: true,
      immediate: true
    });
    const logo = ref("");
    const webSiteName = ref("");
    let getLogo = async () => {
      const responseStatus = await requestDataPromise("/web/getWebsiteHead", {
        method: "GET",
        query: {}
      });
      logo.value = responseStatus.data.logo;
      webSiteName.value = responseStatus.data.website_name;
    };
    getLogo();
    let adImg = ref({});
    return (_ctx, _push, _parent, _attrs) => {
      _push(`<header${ssrRenderAttrs(_attrs)} data-v-4340c4ad><nav class="headerNav" data-v-4340c4ad><div class="inner" data-v-4340c4ad><div class="left" data-v-4340c4ad><span data-v-4340c4ad><a href="http://znxyw.org.cn/" target="_blank" data-v-4340c4ad>\u4E2D\u519C\u5174\u4E1A\u7F51\u56E2</a></span><span data-v-4340c4ad>\u65D7\u4E0B\u7F51\u7AD9\uFF1A<span data-v-4340c4ad>\u519C\u4E1A\u767E\u5F3A\u7F51\u7AD9\uFF08\u653F\u5E9C\u7C7B30\u5F3A\uFF09</span></span></div><div class="right" data-v-4340c4ad><div class="menu" data-v-4340c4ad><button class="reg" data-v-4340c4ad><img src="http://img.bjzxtw.org.cn/master/bjzxtw/public/head/topicon1.png" alt="\u5546\u5708" data-v-4340c4ad>\u5546\u5708 </button><button class="reg" data-v-4340c4ad><img src="http://img.bjzxtw.org.cn/master/bjzxtw/public/head/topicon2.png" alt="\u5E7F\u544A\u670D\u52A1" data-v-4340c4ad>\u5E7F\u544A\u670D\u52A1 </button></div><div class="right-top-menu" data-v-4340c4ad><button class="reg" style="${ssrRenderStyle(!unref(showToken) ? null : { display: "none" })}" data-v-4340c4ad><img src="http://img.bjzxtw.org.cn/master/bjzxtw/public/head/topicon3.png" alt="\u767B\u5F55" data-v-4340c4ad>\u767B\u5F55 </button><button class="reg" style="${ssrRenderStyle(!unref(showToken) ? null : { display: "none" })}" data-v-4340c4ad><img src="http://img.bjzxtw.org.cn/master/bjzxtw/public/head/topicon4.png" alt="\u6CE8\u518C" data-v-4340c4ad>\u6CE8\u518C </button><button class="reg" style="${ssrRenderStyle(unref(showToken) ? null : { display: "none" })}" data-v-4340c4ad><img src="http://img.bjzxtw.org.cn/master/bjzxtw/public/head/topicon3.png" alt="\u7528\u6237\u4FE1\u606F" data-v-4340c4ad>${ssrInterpolate(unref(username))}</button><button class="reg" data-v-4340c4ad><img src="http://img.bjzxtw.org.cn/master/bjzxtw/public/head/searchicon.png" alt="\u641C\u7D22" data-v-4340c4ad>\u641C\u7D22 </button></div>`);
      if (unref(isShow)) {
        _push(`<ul class="userInfo11" data-v-4340c4ad><li data-v-4340c4ad>\u4E2A\u4EBA\u4E2D\u5FC3</li><li data-v-4340c4ad>\u9000\u51FA</li></ul>`);
      } else {
        _push(`<!---->`);
      }
      _push(`</div></div></nav><div class="headerLogo" data-v-4340c4ad><div class="inner" data-v-4340c4ad><img${ssrRenderAttr("src", logo.value)}${ssrRenderAttr("alt", webSiteName.value)} class="left" data-v-4340c4ad>`);
      if (unref(adImg)) {
        _push(`<div class="titlead" data-v-4340c4ad>`);
        if (unref(adImg).image_url == null) {
          _push(`<a href="http://sannongdy.org.cn/" target="_blank"${ssrRenderAttr("title", unref(adImg).introduce)} data-v-4340c4ad><img${ssrRenderAttr("src", unref(adImg).thumb)}${ssrRenderAttr("alt", unref(adImg).introduce)} data-tag="imgurl.ad_tag"${ssrRenderAttr("id", unref(adImg).ad_tag)} data-v-4340c4ad></a>`);
        } else {
          _push(`<a${ssrRenderAttr("href", unref(adImg).image_url)}${ssrRenderAttr("title", unref(adImg).introduce)} data-v-4340c4ad><img${ssrRenderAttr("src", unref(adImg).image_src)}${ssrRenderAttr("alt", unref(adImg).introduce)} data-tag="imgurl.ad_tag"${ssrRenderAttr("id", unref(adImg).ad_tag)} data-v-4340c4ad></a>`);
        }
        _push(`</div>`);
      } else {
        _push(`<!---->`);
      }
      _push(`</div></div>`);
      _push(ssrRenderComponent(unref(ElDialog), {
        modelValue: unref(dialogTableVisible),
        "onUpdate:modelValue": ($event) => isRef(dialogTableVisible) ? dialogTableVisible.value = $event : dialogTableVisible = $event,
        width: "800"
      }, {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(`<div class="tips" data-v-4340c4ad${_scopeId}><p data-v-4340c4ad${_scopeId}><img src="http://img.bjzxtw.org.cn/master/bjzxtw/public/topic/tips.png" data-v-4340c4ad${_scopeId}> \u63D0\u793A:\u6CE8\u518C\u8BF7\u8054\u7CFB\u7BA1\u7406\u5458\u64CD\u4F5C! </p><p data-v-4340c4ad${_scopeId}>\u8054\u7CFB\u7535\u8BDD:010-56019387</p><p data-v-4340c4ad${_scopeId}>QQ \uFF1A 2909421493 \u3001213552413</p></div>`);
          } else {
            return [
              createVNode("div", { class: "tips" }, [
                createVNode("p", null, [
                  createVNode("img", { src: "http://img.bjzxtw.org.cn/master/bjzxtw/public/topic/tips.png" }),
                  createTextVNode(" \u63D0\u793A:\u6CE8\u518C\u8BF7\u8054\u7CFB\u7BA1\u7406\u5458\u64CD\u4F5C! ")
                ]),
                createVNode("p", null, "\u8054\u7CFB\u7535\u8BDD:010-56019387"),
                createVNode("p", null, "QQ \uFF1A 2909421493 \u3001213552413")
              ])
            ];
          }
        }),
        _: 1
      }, _parent));
      _push(`</header>`);
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("components/home/pageHead.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : undefined;
};
const __nuxt_component_0 = /* @__PURE__ */ _export_sfc(_sfc_main, [["__scopeId", "data-v-4340c4ad"]]);
const firstNonUndefined = (...args) => args.find((arg) => arg !== undefined);
// @__NO_SIDE_EFFECTS__
function defineNuxtLink(options) {
  const componentName = options.componentName || "NuxtLink";
  function isHashLinkWithoutHashMode(link) {
    return !hashMode && typeof link === "string" && link.startsWith("#");
  }
  function resolveTrailingSlashBehavior(to, resolve) {
    if (!to || options.trailingSlash !== "append" && options.trailingSlash !== "remove") {
      return to;
    }
    if (typeof to === "string") {
      return applyTrailingSlashBehavior(to, options.trailingSlash);
    }
    const path = "path" in to && to.path !== undefined ? to.path : resolve(to).path;
    const resolvedPath = {
      ...to,
      name: undefined,
      // named routes would otherwise always override trailing slash behavior
      path: applyTrailingSlashBehavior(path, options.trailingSlash)
    };
    return resolvedPath;
  }
  function useNuxtLink(props) {
    var _a, _b, _c;
    const router = useRouter();
    const config = useRuntimeConfig();
    const hasTarget = computed(() => !!props.target && props.target !== "_self");
    const isAbsoluteUrl = computed(() => {
      const path = props.to || props.href || "";
      return typeof path === "string" && hasProtocol(path, { acceptRelative: true });
    });
    const builtinRouterLink = resolveComponent("RouterLink");
    const useBuiltinLink = builtinRouterLink && typeof builtinRouterLink !== "string" ? builtinRouterLink.useLink : undefined;
    const isExternal = computed(() => {
      if (props.external) {
        return true;
      }
      const path = props.to || props.href || "";
      if (typeof path === "object") {
        return false;
      }
      return path === "" || isAbsoluteUrl.value;
    });
    const to = computed(() => {
      const path = props.to || props.href || "";
      if (isExternal.value) {
        return path;
      }
      return resolveTrailingSlashBehavior(path, router.resolve);
    });
    const link = isExternal.value ? undefined : useBuiltinLink == null ? undefined : useBuiltinLink({ ...props, to });
    const href = computed(() => {
      var _a3;
      var _a2;
      if (!to.value || isAbsoluteUrl.value || isHashLinkWithoutHashMode(to.value)) {
        return to.value;
      }
      if (isExternal.value) {
        const path = typeof to.value === "object" && "path" in to.value ? resolveRouteObject(to.value) : to.value;
        const href2 = typeof path === "object" ? router.resolve(path).href : path;
        return resolveTrailingSlashBehavior(
          href2,
          router.resolve
          /* will not be called */
        );
      }
      if (typeof to.value === "object") {
        return (_a3 = (_a2 = router.resolve(to.value)) == null ? undefined : _a2.href) != null ? _a3 : null;
      }
      return resolveTrailingSlashBehavior(
        joinURL(config.app.baseURL, to.value),
        router.resolve
        /* will not be called */
      );
    });
    return {
      to,
      hasTarget,
      isAbsoluteUrl,
      isExternal,
      //
      href,
      isActive: (_a = link == null ? undefined : link.isActive) != null ? _a : computed(() => to.value === router.currentRoute.value.path),
      isExactActive: (_b = link == null ? undefined : link.isExactActive) != null ? _b : computed(() => to.value === router.currentRoute.value.path),
      route: (_c = link == null ? undefined : link.route) != null ? _c : computed(() => router.resolve(to.value)),
      async navigate() {
        await navigateTo(href.value, { replace: props.replace, external: isExternal.value || hasTarget.value });
      }
    };
  }
  return defineComponent({
    name: componentName,
    props: {
      // Routing
      to: {
        type: [String, Object],
        default: undefined,
        required: false
      },
      href: {
        type: [String, Object],
        default: undefined,
        required: false
      },
      // Attributes
      target: {
        type: String,
        default: undefined,
        required: false
      },
      rel: {
        type: String,
        default: undefined,
        required: false
      },
      noRel: {
        type: Boolean,
        default: undefined,
        required: false
      },
      // Prefetching
      prefetch: {
        type: Boolean,
        default: undefined,
        required: false
      },
      prefetchOn: {
        type: [String, Object],
        default: undefined,
        required: false
      },
      noPrefetch: {
        type: Boolean,
        default: undefined,
        required: false
      },
      // Styling
      activeClass: {
        type: String,
        default: undefined,
        required: false
      },
      exactActiveClass: {
        type: String,
        default: undefined,
        required: false
      },
      prefetchedClass: {
        type: String,
        default: undefined,
        required: false
      },
      // Vue Router's `<RouterLink>` additional props
      replace: {
        type: Boolean,
        default: undefined,
        required: false
      },
      ariaCurrentValue: {
        type: String,
        default: undefined,
        required: false
      },
      // Edge cases handling
      external: {
        type: Boolean,
        default: undefined,
        required: false
      },
      // Slot API
      custom: {
        type: Boolean,
        default: undefined,
        required: false
      }
    },
    useLink: useNuxtLink,
    setup(props, { slots }) {
      useRouter();
      const { to, href, navigate, isExternal, hasTarget, isAbsoluteUrl } = useNuxtLink(props);
      ref(false);
      const el = undefined;
      const elRef = undefined;
      async function prefetch(nuxtApp = useNuxtApp()) {
        {
          return;
        }
      }
      return () => {
        var _a;
        if (!isExternal.value && !hasTarget.value && !isHashLinkWithoutHashMode(to.value)) {
          const routerLinkProps = {
            ref: elRef,
            to: to.value,
            activeClass: props.activeClass || options.activeClass,
            exactActiveClass: props.exactActiveClass || options.exactActiveClass,
            replace: props.replace,
            ariaCurrentValue: props.ariaCurrentValue,
            custom: props.custom
          };
          if (!props.custom) {
            routerLinkProps.rel = props.rel || undefined;
          }
          return h(
            resolveComponent("RouterLink"),
            routerLinkProps,
            slots.default
          );
        }
        const target = props.target || null;
        const rel = firstNonUndefined(
          // converts `""` to `null` to prevent the attribute from being added as empty (`rel=""`)
          props.noRel ? "" : props.rel,
          options.externalRelAttribute,
          /*
          * A fallback rel of `noopener noreferrer` is applied for external links or links that open in a new tab.
          * This solves a reverse tabnapping security flaw in browsers pre-2021 as well as improving privacy.
          */
          isAbsoluteUrl.value || hasTarget.value ? "noopener noreferrer" : ""
        ) || null;
        if (props.custom) {
          if (!slots.default) {
            return null;
          }
          return slots.default({
            href: href.value,
            navigate,
            prefetch,
            get route() {
              if (!href.value) {
                return undefined;
              }
              const url = new URL(href.value, "http://localhost");
              return {
                path: url.pathname,
                fullPath: url.pathname,
                get query() {
                  return parseQuery(url.search);
                },
                hash: url.hash,
                params: {},
                name: undefined,
                matched: [],
                redirectedFrom: undefined,
                meta: {},
                href: href.value
              };
            },
            rel,
            target,
            isExternal: isExternal.value || hasTarget.value,
            isActive: false,
            isExactActive: false
          });
        }
        return h("a", { ref: el, href: href.value || null, rel, target }, (_a = slots.default) == null ? undefined : _a.call(slots));
      };
    }
  });
}
const __nuxt_component_2 = /* @__PURE__ */ defineNuxtLink(nuxtLinkDefaults);
function applyTrailingSlashBehavior(to, trailingSlash) {
  const normalizeFn = trailingSlash === "append" ? withTrailingSlash : withoutTrailingSlash;
  const hasProtocolDifferentFromHttp = hasProtocol(to) && !to.startsWith("http");
  if (hasProtocolDifferentFromHttp) {
    return to;
  }
  return normalizeFn(to, true);
}

export { __nuxt_component_0 as _, requestHome as a, __nuxt_component_2 as b, useState as c, requestDataPromise as r, useSeoMeta as u };
//# sourceMappingURL=nuxt-link-CT-wIPZG.mjs.map
